@@ -1,6 +1,5 @@
 import base64
 import json
-from decimal import Decimal
 import pydash
 from aws_lambda_stream.utils.json_encoder import JSONEncoder
 
@@ -18,7 +17,7 @@ def from_kinesis(event):
             **uow,
             'event': {
                 'id': uow['record']['eventID'],
-                **json.loads(uow['event'], parse_float=Decimal)
+                **json.loads(uow['event'])
             },
         }
     ).value()
@@ -33,7 +32,9 @@ def to_kinesis_records(events):
                 'awsRegion': 'us-west-2',
                 'kinesis': {
                     'sequenceNumber': f"{i}",
-                    'data': base64.b64encode(json.dumps(e, cls=JSONEncoder).encode('utf-8'))
+                    'data': base64.b64encode(
+                        json.dumps(e, cls=JSONEncoder).encode('utf-8')
+                    ).decode('utf-8')
                 }
             }
             for i,e in enumerate(events)
